@@ -16,12 +16,12 @@ class WKFSAdapter:
         self,
         host,
         auth_host,
-        logging=True,
+        logging=False,
         wkfs_config=None,
-        template_package_name=None,
+        template_name=None,
     ):
         self._api_handler = APIHandler(host, headers={}, logging=logging)
-        self.template_package_name = template_package_name
+        self.template_name = template_name
 
         self.wkfs_config = wkfs_config
         self.host = host
@@ -31,7 +31,7 @@ class WKFSAdapter:
         self,
         transaction_data_json_input: str,
         e_sign: bool = False,
-        product: str = None,
+        package_name: str = None,
         log_config: dict = None,
         access_token: str = None,
         ezConfig: str = None,
@@ -42,15 +42,14 @@ class WKFSAdapter:
         :param
             transaction_data_json_input: Json input from the calling application to generate the transaction xml
             e_sign: Indicating whether e signature co-ordinates should be part of response
-            product: The product for which documents are generated.
+            package_name: The package for which documents are generated.
             access_token: The access token required to authenticate the caller.
-
         """
 
         # TODO: Plug in the Json Schema validator here?
 
         # If the template_package_name is not specified, then pick from the templates folder in the application
-        if self.template_package_name is None:
+        if self.template_name is None:
             env = Environment(
                 loader=FileSystemLoader(f"{os.getcwd()}/templates"),
                 autoescape=select_autoescape(),
@@ -60,20 +59,22 @@ class WKFSAdapter:
         else:
             # Pick the templates folder from the specified package.
             env = Environment(
-                loader=PackageLoader(self.template_package_name),
+                loader=PackageLoader(self.template_name),
                 autoescape=select_autoescape(),
+                trim_blocks=True,
+                lstrip_blocks=True,
             )
         wkfs_id = self.wkfs_config["wkfs_id"]
-        products = self.wkfs_config["products"]
+        packages = self.wkfs_config["packages"]
         account_id = self.wkfs_config["account_id"]
 
-        wkfs_product = None
+        wkfs_package_name = None
         wkfs_xml = None
-        for config_product in products:
-            wkfs_product = config_product.get("name")
-            if wkfs_product == product:
-                wkfs_package = config_product.get("wkfs_package")
-                wkfs_xml = config_product.get("wkfs_xml")
+        for package in packages:
+            wkfs_package_name = package.get("name")
+            if wkfs_package_name == package_name:
+                wkfs_package = package.get("package_or_packet")
+                wkfs_xml = package.get("template_xml")
                 break
 
         if None in [wkfs_package, wkfs_xml]:
